@@ -170,8 +170,10 @@ class Builder(object):
             env.AppendUnique(LIBPATH=self.solution.libpath)
             job = env.Program(target=cname + '.elf', source=sources)
 
-            env.Decider(config_file_decider)
+            env.Decider(decide_if_changed)
+            # add recompiled file check.
             env.Depends(job, self.solution.depend_libs)
+            env.Depends(job, self.solution.ld_script)
             env.Default(job)
         else:
             job = env.StaticLibrary(os.path.join(
@@ -198,7 +200,7 @@ class Builder(object):
         env.Default(job4)
 
 
-def config_file_decider(dependency, target, prev_ni, repo_node=None):
+def decide_if_changed(dependency, target, prev_ni, repo_node=None):
     # print(dependency, prev_ni)
     if not prev_ni:
         return True
