@@ -14,6 +14,7 @@ from .log import logger
 
 desc_width = 50
 
+
 class HardwareInfo:
     def __init__(self, dic):
         self.cpu_id = ''
@@ -89,7 +90,7 @@ class build_config:
                 self.__dict__[k] = v
 
     def out(self):
-        text = 'build_config:\n'
+        text = ''
         for k in ['cflag', 'cxxflag', 'asmflag', 'ldflag']:
             value = self.__dict__[k]
             if value:
@@ -118,7 +119,6 @@ class build_config:
             if define_text:
                 text += '  define:\n' + define_text
 
-
         for k in ['include', 'internal_include', 'libs', 'libpath']:
             if len(self.__dict__[k]) > 0:
                 value_text = ''
@@ -128,6 +128,9 @@ class build_config:
                 if value_text:
                     text += '  %s:\n%s' % (k, value_text)
 
+        if text:
+            text = 'build_config:\n' + text
+
         return text
 
 
@@ -186,6 +189,7 @@ class Package(object):
                 '%s `type` must be "solution" or "common" or "board" or "chip".' % filename)
             exit(-1)
 
+
     def show(self):
         for k, v in self.__dict__.items():
             if not v:
@@ -205,7 +209,7 @@ class Package(object):
         text = '''
 ## 第一部分： 基础信息
 {name}{version}{description}{type}
-{tag}{keywords}{homepage}{yoc_version}{license}
+{tag}{keywords}{homepage}{yoc_version}{author}{license}
 ## 第二部分：依赖信息
 #           指定该组件依赖的组件及版本，版本支持条件比较，支持：>=v1.0, >v1.0, ==v1.0, <=v1.0, <v1.0, v1.0
 #           未指定条件时，默认为 ==，如 v1.0 与 ==v1.0
@@ -264,53 +268,57 @@ class Package(object):
 #   flash_program: bin/flash_program.elf   # <可选项> 芯片全局烧写程序
 {hw_info}
 ## 第四部分：编译连接信息
-# build_config:                       # <可选项> 编译配置项
-#   include:                          # <可选项> 编译时，影响编译器的-I 参数 ,全局有效
-#     - src                           #        include 只能是该软件包下的目录，不能使用外部目录
-#   internal_include:                 # <可选项> 编译时，影响编译器的-I 参数 ,组件内有效
+# build_config:                            # <可选项> 编译配置项
+#   include:                               # <可选项> 编译时，影响编译器的-I 参数 ,全局有效
+#     - src                                #        include 只能是该软件包下的目录，不能使用外部目录
+#   internal_include:                      # <可选项> 编译时，影响编译器的-I 参数 ,组件内有效
 #     - include
-#   cflag: ''                         # <可选项> C 编译器所需要要的编译参数
-#   cxxflag: ''                       # <可选项> CXX 编译器所需要要的编译参数
-#   asmflag: ''                       # <可选项> 汇编器所需要要参数
-#   define:                           # <可选项> 宏定义, 增加编译器的-D 选项,如：
-#     XXX: 1                          #   -DXXX=1
-#     AAA: 1                          #   -DAAA
-#     STR: "abc"                      #   -DSTR=\"abc\"
-#   libs:                             # 该组件中支持的二进制静态库,如：libxxx.a, libyyy.a
-#     - xxx                           #   -lxxx
-#     - yyy                           #   -lyyy
-#   libpath:                          # 指定静态库所在的路径（相对于该组件路径）
-#     - libs                          #   -Llibs
+#   cflag: ''                              # <可选项> C 编译器所需要要的编译参数
+#   cxxflag: ''                            # <可选项> CXX 编译器所需要要的编译参数
+#   asmflag: ''                            # <可选项> 汇编器所需要要参数
+#   define:                                # <可选项> 宏定义, 增加编译器的-D 选项,如：
+#     XXX: 1                               #   -DXXX=1
+#     AAA: 1                               #   -DAAA
+#     STR: "abc"                           #   -DSTR=\"abc\"
+#   libs:                                  # 该组件中支持的二进制静态库,如：libxxx.a, libyyy.a
+#     - xxx                                #   -lxxx
+#     - yyy                                #   -lyyy
+#   libpath:                               # 指定静态库所在的路径（相对于该组件路径）
+#     - libs                               #   -Llibs
 {build_config}
-# source_file:                        # <可选项> 指定参与编译的源代码文件，支持通配符，采用相对路径
-#   - src/*.c                         # 例：组件 src 目录下所有的扩展名为 c 的源代码文件
+# source_file:                             # <可选项> 指定参与编译的源代码文件，支持通配符，采用相对路径
+#   - src/*.c                              # 例：组件 src 目录下所有的扩展名为 c 的源代码文件
 {source_file}
 ## 第五部分：配置信息
-# def_config:                        # 组件的可配置项
+# def_config:                              # 组件的可配置项
 #   CONFIG_DEBUG: y
 #   CONFIG_PARAM_NOT_CHECK: y
 #   CONFIG_CLI: y
 {def_config}
 ## 第六部分：安装信息
 # install:
-#   - dest: include/    # 安装的目的路径 dest是相当路径，通常是相对于YoC SDK 安装目录
-#     source:           # 安装源列表
-#      - src/*.h        # 支持通配符，相对路径
+#   - dest: include/                       # 安装的目的路径 dest是相当路径，通常是相对于YoC SDK 安装目录
+#     source:                              # 安装源列表
+#      - src/*.h                           # 支持通配符，相对路径
 {install}
 ## 第七部分：导出部分
 {export}'''
 
         text = text.format(
-            name=self.text_out('name', self.name, '# <必选项> 包名称 （符合C语言变量命名规则），长度少于等于64字节'),
+            name=self.text_out('name', self.name,
+                               '# <必选项> 包名称 （符合C语言变量命名规则），长度少于等于64字节'),
             version=self.text_out('version', self.version),
-            description=self.text_out('description', self.description, '# <必选项> 建议至少20字以上'),
+            description=self.text_out(
+                'description', self.description, '# <必选项> 建议至少20字以上'),
             tag=self.text_out('tag', self.tag, "# <可选项> 组件分类，缺省值： ''"),
             yoc_version=self.text_out('yoc_version', self.yoc_version),
             keywords=self.keywords_out(),
             author=self.author_out(),
-            license=self.text_out('license', self.license, '# <可选项> 源代码的许可证，要确保所有代码、文件的许可证不冲突。如：MIT，Apache license v2.0，BSD'),
+            license=self.text_out(
+                'license', self.license, '# <可选项> 源代码的许可证，要确保所有代码、文件的许可证不冲突。如：MIT，Apache license v2.0，BSD'),
             homepage=self.text_out('homepage', self.homepage),
-            type=self.text_out('type', self.type,'# <可选项> 组件类型，为：solution, chip, board, common，缺省值 common'),
+            type=self.text_out(
+                'type', self.type, '# <可选项> 组件类型，为：solution, chip, board, common，缺省值 common'),
             depends=self.depends_out(),
             source_file=self.fsource_file_out(),
             install=self.install_out('install', self.install),
@@ -328,28 +336,28 @@ class Package(object):
         except:
             print("Generate %s file failed." % self.filename)
 
-
     def text_out(self, k, v, desc=''):
         k_len = len(k)
         if type(v) != str:
             v = str(v)
         v_len = string_len(v)
         if desc:
-            desc = ' ' * (desc_width - k_len - v_len) + desc
+            desc = ' ' * (desc_width - k_len - v_len - 1) + desc
         if v:
-            return '{}: {}{}\n'.format(k, v, desc)
+            return '{}: {} {}'.format(k, v, desc).strip() + '\n'
         return ''
 
     def author_out(self):
         text = ''
-        if len(self.author) > 0:
+        if self.author:
             if type(self.author) == str:
                 text = self.text_out('author', self.author, '# <可选项> 原作者信息')
             else:
-                text = 'author:' + ' ' * (desc_width - 7) + '# <可选项> 原作者信息\n'
+                text = 'author:' + ' ' * (desc_width - 5) + '# <可选项> 原作者信息\n'
                 for k, v in self.author.items():
                     text += '  {}: {}\n'.format(k, v)
 
+
         return text
 
     def dict_out(self, k, v):
@@ -363,7 +371,8 @@ class Package(object):
     def keywords_out(self):
         text = ''
         if len(self.keywords) > 0:
-            text = 'keywords:' + ' '*(desc_width - 7) + '# <可选项> 标签，会影响到组件被搜索的效果，合理的标签很重要\n'
+            text = 'keywords:' + ' ' * \
+                (desc_width - 7) + '# <可选项> 标签，会影响到组件被搜索的效果，合理的标签很重要\n'
         for k in self.keywords:
             text += '  - %s\n' % k
 
