@@ -72,7 +72,7 @@ class Solution:
 
         # find current solution & board component
         for component in self.components:
-            if component.path == current_pwd() and component.type == 'solution':
+            if component.path == os.getcwd() and component.type == 'solution':
                 self.solution_component = component
                 self.board_component = self.components.get(
                     self.solution_component.hw_info.board_name)
