@@ -47,4 +47,7 @@ component export.
         if p:
             dest = os.path.join(path, p, component.name)
             print("export `%s` to %s" % (component.name, dest))
-            shutil.copytree(component.path, dest)
+            try:
+                shutil.copytree(component.path, dest)
+            except:
+                pass
