@@ -53,9 +53,6 @@ def yaml_load(filename):
         exit(-1)
 
 
-def current_pwd():
-    return os.getcwd()
-
 
 def home_path(path=''):
     return os.path.join(os.path.expanduser('~'), path)
@@ -147,6 +144,8 @@ def wget(url, out_file):
     return urlretrieve(url, out_file, barProcess)
 
 
+
+# make_archive(base_name, format, root_dir=None, base_dir=None, verbose=0,dry_run=0, owner=None, group=None, logger=None)
 def dfs_get_zip_file(input_path, result):
     files = os.listdir(input_path)
     for file in files:
