@@ -30,7 +30,7 @@ class Configure:
         self.repo = 'git@gitee.com:yocopen'
         self.init = False
 
-        self.yoc_path = current_pwd()
+        self.yoc_path = os.getcwd()
         if not self.yoc_path:
             self.yoc_path = '/'
         tmp_path = self.yoc_path
@@ -149,10 +149,9 @@ class YoC:
                 depends_on.append(c)
         return depends_on
 
-
     def getSolution(self):
         for component in self.components:
-            if component.path == current_pwd():
+            if component.path == os.getcwd():
                 components = self.components.get_depend(component)
                 components.append(component)
                 solution = Solution(components)
@@ -236,7 +235,6 @@ class YoC:
             pickle.dump(self.occ_components, f)
             self.conf.save()
 
-
     def occ_update(self):
         if self.occ == None:
             self.occ = self.occ = OCC(self.conf)
